<h1>
  <img src="https://github.com/jpsca/jinjax/raw/main/logo.png"width="48" height="48" align="top">
  JinjaX
</h1>

From chaos to clarity: The power of components in your server-side-rendered Python web app.

**Documentation:** https://jinjax.scaletti.dev/

Write server-side components as single Jinja template files.
Use them as HTML tags without doing any importing.


## Roadmap

- Slots
- Autoloading assets (optional?) (`Card.jinja` autoloads `Card.css` and/or `Card.js` if exists)
- ...
